==> v2.3.4.tar.gz: privacyguides.org/docs/notebooks.en.md <==
---
title: "Notebooks"
icon: material/notebook-edit-outline
---

Keep track of your notes and journalings without giving them to a third party.

If you are currently using an application like Evernote, Google Keep, or Microsoft OneNote, we suggest you pick an alternative here that supports [End-to-end encryption (E2EE)](https://en.wikipedia.org/wiki/End-to-end_encryption).

## Cloud based

### Joplin

!!! recommendation

    ![Joplin logo](assets/img/notebooks/joplin.svg){ align=right }

    **Joplin** is a free, open-source, and fully-featured note-taking and to-do application which can handle a large number of markdown notes organized into notebooks and tags. It offers end-to-end encryption and can sync through Nextcloud, Dropbox, and more. It also offers easy import from Evernote and plain-text notes.

    [Visit joplinapp.org](https://joplinapp.org/){ .md-button .md-button--primary }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://joplinapp.org/#desktop-applications)
    - [:fontawesome-brands-apple: macOS](https://joplinapp.org/#desktop-applications)
    - [:fontawesome-brands-linux: Linux](https://joplinapp.org/#desktop-applications)
    - [:fontawesome-brands-firefox-browser: Firefox](https://addons.mozilla.org/firefox/addon/joplin-web-clipper/)
    - [:fontawesome-brands-chrome: Chrome](https://chrome.google.com/webstore/detail/joplin-web-clipper/alofnhikmmkdbbbgpnglcpdollgjjfek)
    - [:fontawesome-brands-google-play: Google Play](https://play.google.com/store/apps/details?id=net.cozic.joplin)
    - [:pg-f-droid: F-Droid](https://f-droid.org/en/packages/net.cozic.joplin)
    - [:fontawesome-brands-android: Android](https://joplinapp.org/#mobile-applications)
    - [:fontawesome-brands-github: GitHub](https://github.com/laurent22/joplin)

!!! warning

    Note: As of Dec 2018, Joplin does not support password/pin protection for the application itself or individual notes/notebooks. Data is still encrypted in transit and at sync location using your master key. See [open issue](https://github.com/laurent22/joplin/issues/289).

### Standard Notes

!!! recommendation

    ![Standard Notes logo](assets/img/notebooks/standard-notes.svg){ align=right }

    Standard Notes is a simple and private notes app that makes your notes easy and available everywhere you are. It features end-to-end encryption on every platform, and a powerful desktop experience with themes and custom editors. It has also been [independently audited (PDF)](https://s3.amazonaws.com/standard-notes/security/Report-SN-Audit.pdf).

    [Visit standardnotes.org](https://standardnotes.org/){ .md-button .md-button--primary }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://standardnotes.org/#get-started)
    - [:fontawesome-brands-apple: macOS](https://standardnotes.org/#get-started)
    - [:fontawesome-brands-linux: Linux](https://standardnotes.org/#get-started)
    - [:fontawesome-brands-google-play: Google Play](https://play.google.com/store/apps/details?id=com.standardnotes)
    - [:fontawesome-brands-app-store-ios: App Store](https://apps.apple.com/app/id1285392450)
    - [:octicons-browser-16: Browser](https://app.standardnotes.org/)
    - [:fontawesome-brands-github: GitHub](https://github.com/standardnotes)

## Worth Mentioning

- [EteSync](https://www.etesync.com/) - Secure, end-to-end encrypted, and privacy respecting sync for your contacts, calendars, tasks and notes.
- [Paperwork](https://paperwork.cloud/) - An open-source and self-hosted solution. For PHP / MySQL servers.
- [Org-mode](https://orgmode.org) - A major mode for GNU Emacs. Org-mode is for keeping notes, maintaining TODO lists, planning projects, and authoring documents with a fast and effective plain-text system.

==> v2.4.2.tar.gz: privacyguides.org/docs/notebooks.en.md <==
---
title: "Notebooks"
icon: material/notebook-edit-outline
---

Keep track of your notes and journalings without giving them to a third party.

If you are currently using an application like Evernote, Google Keep, or Microsoft OneNote, we suggest you pick an alternative here that supports E2EE.

## Cloud based

### Joplin

!!! recommendation

    ![Joplin logo](assets/img/notebooks/joplin.svg){ align=right }

    **Joplin** is a free, open-source, and fully-featured note-taking and to-do application which can handle a large number of markdown notes organized into notebooks and tags. It offers E2EE and can sync through Nextcloud, Dropbox, and more. It also offers easy import from Evernote and plain-text notes.

    [Visit joplinapp.org](https://joplinapp.org/){ .md-button .md-button--primary }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://joplinapp.org/#desktop-applications)
    - [:fontawesome-brands-apple: macOS](https://joplinapp.org/#desktop-applications)
    - [:fontawesome-brands-linux: Linux](https://joplinapp.org/#desktop-applications)
    - [:fontawesome-brands-firefox-browser: Firefox](https://addons.mozilla.org/firefox/addon/joplin-web-clipper/)
    - [:fontawesome-brands-chrome: Chrome](https://chrome.google.com/webstore/detail/joplin-web-clipper/alofnhikmmkdbbbgpnglcpdollgjjfek)
    - [:fontawesome-brands-google-play: Google Play](https://play.google.com/store/apps/details?id=net.cozic.joplin)
    - [:pg-f-droid: F-Droid](https://f-droid.org/en/packages/net.cozic.joplin)
    - [:fontawesome-brands-android: Android](https://joplinapp.org/#mobile-applications)
    - [:fontawesome-brands-github: GitHub](https://github.com/laurent22/joplin)

!!! warning

    Note: As of Dec 2018, Joplin does not support password/pin protection for the application itself or individual notes/notebooks. Data is still encrypted in transit and at sync location using your master key. See [open issue](https://github.com/laurent22/joplin/issues/289).

### Standard Notes

!!! recommendation

    ![Standard Notes logo](assets/img/notebooks/standard-notes.svg){ align=right }

    Standard Notes is a simple and private notes app that makes your notes easy and available everywhere you are. It features E2EE on every platform, and a powerful desktop experience with themes and custom editors. It has also been [independently audited (PDF)](https://s3.amazonaws.com/standard-notes/security/Report-SN-Audit.pdf).

    [Visit standardnotes.org](https://standardnotes.org/){ .md-button .md-button--primary }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://standardnotes.org/#get-started)
    - [:fontawesome-brands-apple: macOS](https://standardnotes.org/#get-started)
    - [:fontawesome-brands-linux: Linux](https://standardnotes.org/#get-started)
    - [:fontawesome-brands-google-play: Google Play](https://play.google.com/store/apps/details?id=com.standardnotes)
    - [:fontawesome-brands-app-store-ios: App Store](https://apps.apple.com/app/id1285392450)
    - [:octicons-browser-16: Browser](https://app.standardnotes.org/)
    - [:fontawesome-brands-github: GitHub](https://github.com/standardnotes)

## Worth Mentioning

- [EteSync](https://www.etesync.com/) - Secure, end-to-end encrypted, and privacy respecting sync for your contacts, calendars, tasks and notes.
- [Paperwork](https://paperwork.cloud/) - An open-source and self-hosted solution. For PHP / MySQL servers.
- [Org-mode](https://orgmode.org) - A major mode for GNU Emacs. Org-mode is for keeping notes, maintaining TODO lists, planning projects, and authoring documents with a fast and effective plain-text system.

--8<-- "includes/abbreviations.en.md"
